# Argument descriptions repeated > 1:

#' Helper for consistent documentation of `dateRange`.
#'
#' @param dateRange A vector of two dates defining the desired study period.
#' Only the `start_date` column of the OMOP table is checked to ensure it falls within this range.
#' If `dateRange` is `NULL`, no restriction is applied.
#'
#'
#' @name dateRange-startDate
#' @keywords internal
NULL

#' Helper for consistent documentation of `interval`.
#'
#' @param interval Time interval to stratify by. It can either be "years", "quarters", "months" or "overall".
#'
#'
#' @name interval
#' @keywords internal
NULL
